var duiRegExp = /(^\d{8})-(\d$)/;
/**
 * Verifies that given DUI format is valid
 *
 * @param  {string} str       A string representing DUI digits (with hyphen)
 * @returns {boolean}         Validity of the given DUI
 */
function isDUI(str) {
    if (!duiRegExp.test(str))
        return false;
    var sum = 0;
    var _a = str.split('-'), digits = _a[0], verifier = _a[1];
    for (var i = 0; i < digits.length; i++) {
        sum += Number(digits[i]) * (digits.length + 1 - i);
    }
    return Number(verifier) === 10 - (sum % 10);
}

// TODO: map the whole municipality's list
var municipalitiesLookup = {
    '01': 12,
    '02': 13,
    '03': 16,
    '04': 33,
    '05': 22,
    '06': 19,
    '07': 16,
    '08': 22,
    '09': 9,
    '10': 13,
    '11': 23,
    '12': 20,
    '13': 26,
    '14': 18,
};
/**
 * Verifies that given municipality code is valid foreign code
 *
 * @param  {string} code      A string representing municipality digits
 * @returns {boolean}         Foreign validity of the given municipality
 */
function isForeignCode(code) {
    return code.startsWith('9');
}
/**
 * Verifies that given municipality code is valid national code
 *
 * @param  {string} code      A string representing municipality digits
 * @returns {boolean}         National validity of the given municipality
 */
function isNationalCode(code) {
    if (!code.startsWith('0') && !code.startsWith('1'))
        return false;
    var department = code.substring(0, 2);
    var municipality = code.substring(2);
    return municipalitiesLookup[department] >= Number(municipality);
}
/**
 * Verifies that given municipality code is valid
 *
 * @param  {string} code      A string representing municipality digits
 * @returns {boolean}         Validity of the given municipality
 */
function isMunicipalityCode(code) {
    return code.length === 4 && (isForeignCode(code) || isNationalCode(code));
}

var nitRegExp = /(^\d{4})-(\d{6})-(\d{3})-(\d$)/;
/**
 * Calculates given the digits of a old NIT which is the check digit for that NIT
 * @param  {string} digits     A string representing NIT digits (without hyphen)
 * @returns {number}         Check digit of the given NIT
 */
function checkDigitOldFormat(digits) {
    var sum = 0;
    for (var i = 0; i < digits.length; i++) {
        sum += Number(digits[i]) * (digits.length + 1 - i);
    }
    sum %= 11;
    return sum;
}
/**
 * Calculates given the digits of a NIT which is the check digit for that NIT
 * @param  {string} digits     A string representing NIT digits (without hyphen)
 * @returns {number}         check digit of the given NIT
 */
function checkDigit(digits) {
    var sum = 0;
    for (var i = 0; i < digits.length; i++) {
        sum +=
            Number(digits[i]) * (3 + 6 * Math.floor(Math.abs((i + 5) / 6)) - (i + 1));
    }
    sum %= 11;
    return sum > 1 ? 11 - sum : 0;
}
/**
 * Calculates the probable full-year birthday of the person, given the Year digits from Date of birth of the NIT
 * @param  {string} year     The 2 year digits from the NIT date of birth
 * @returns {string}         Probable full year of birth
 */
function getFullYear(year) {
    return Number(year) >=
        Number(new Date().getFullYear().toString().substr(-2)) + 1
        ? '19'.concat(year)
        : '20'.concat(year);
}
/**
 * Verifies that given the Date of birth from the NIT is valid
 * @param  {string} str      A string representing the date of birth section from the NIT
 * @returns {boolean}        Validity of the given date of birth
 */
function isDate(str) {
    var year = getFullYear(str.substring(4));
    var month = str.substring(2, 4);
    var day = str.substring(0, 2);
    var date = new Date(year + "/" + month + "/" + day);
    return date && Number(date.getMonth()) + 1 === Number(month);
}
/**
 * Verifies that given NIT format is valid
 *
 * @param  {string} str       A string representing NIT digits (with hyphen)
 * @returns {boolean}         Validity of the given NIT
 */
function isNIT(str) {
    if (!nitRegExp.test(str))
        return false;
    var _a = str.split('-'), municipality = _a[0], birthdate = _a[1], correlative = _a[2], verifier = _a[3];
    if (!isMunicipalityCode(municipality) || !isDate(birthdate))
        return false;
    var digits = municipality + birthdate + correlative;
    var sum = correlative.startsWith('0')
        ? checkDigitOldFormat(digits)
        : checkDigit(digits);
    return Number(verifier) === sum;
}

export { isDUI, isNIT };
//# sourceMappingURL=index.es.js.map
